@@ -111,12 +111,12 @@ GMManager::GMManager ()
   GatewayIPTimer.SetNotifier (PCREATE_NOTIFIER (OnGatewayIPTimeout));
   GatewayIPTimer.RunContinuous (PTimeInterval (5));
 
+  IPChangedTimer.SetNotifier (PCREATE_NOTIFIER (OnIPChanged));
+  IPChangedTimer.RunContinuous (120000);
   NoIncomingMediaTimer.SetNotifier (PCREATE_NOTIFIER (OnNoIncomingMediaTimeout));
 
   missed_calls = 0;
 
-  OutgoingCallTimer.SetNotifier (PCREATE_NOTIFIER (OnOutgoingCall));
-
   h323EP = NULL;
   sipEP = NULL;
   pcssEP = NULL;
@@ -170,14 +170,10 @@ GMManager::SetUpCall (const PString & call_addr,
   called_address = call_addr;
   lca_access_mutex.Signal();
   
-  OutgoingCallTimer.RunContinuous (PTimeInterval (5));
   result = OpalManager::SetUpCall ("pc:*", call_addr, call_token, NULL);
 
-  if (!result) {
-
-    OutgoingCallTimer.Stop ();
+  if (!result) 
     pcssEP->PlaySoundEvent ("busy_tone_sound");
-  }
   
   return result;
 }
@@ -936,9 +932,6 @@ GMManager::OnEstablishedCall (OpalCall &call)
   /* Start refreshing the stats */
   RTPTimer.RunContinuous (PTimeInterval (0, 1));
 
-  /* Stop the Timers */
-  OutgoingCallTimer.Stop ();
-
   /* Update internal state */
   SetCallingState (GMManager::Connected);
   SetCurrentCallToken (call.GetToken ());
@@ -947,9 +940,7 @@ GMManager::OnEstablishedCall (OpalCall &call)
   gnomemeeting_threads_enter ();
   if (called_address.IsEmpty ()) 
     gm_main_window_set_call_url (main_window, GMURL ().GetDefaultURL ());
-  gm_main_window_update_calling_state (main_window, GMManager::Connected);
   gm_main_window_set_stay_on_top (main_window, stay_on_top);
-  gm_main_window_update_calling_state (main_window, GMManager::Connected);
   gm_statusicon_update_full (statusicon, GMManager::Connected,
 			     icm, forward_on_busy);
 #ifdef HAS_DBUS
@@ -1007,6 +998,7 @@ GMManager::OnEstablished (OpalConnection &connection)
   gm_main_window_set_status (main_window, msg);
   gm_main_window_flash_message (main_window, msg);
   gm_chat_window_push_info_message (chat_window, NULL, msg);
+  gm_main_window_update_calling_state (main_window, GMManager::Connected);
   gm_chat_window_update_calling_state (chat_window, 
 				       utf8_name,
 				       utf8_url, 
@@ -1062,7 +1054,6 @@ GMManager::OnClearedCall (OpalCall & call)
   BOOL forward_on_busy = FALSE;
   IncomingCallMode icm = AVAILABLE;
   ViewMode m = SOFTPHONE;
-  PString old_token;
 
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
   chat_window = GnomeMeeting::Process ()->GetChatWindow ();
@@ -1085,7 +1076,6 @@ GMManager::OnClearedCall (OpalCall & call)
   gnomemeeting_threads_leave ();
   
   /* Stop the Timers */
-  OutgoingCallTimer.Stop ();
   NoIncomingMediaTimer.Stop ();
   
   /* we reset the no-data detection */
@@ -1113,14 +1103,14 @@ GMManager::OnClearedCall (OpalCall & call)
   gm_main_window_clear_signal_levels (main_window);
   gm_main_window_set_view_mode (main_window, m);
 #ifdef HAS_DBUS
-  gnomemeeting_dbus_component_set_call_state (dbus_component, old_token,
+  gnomemeeting_dbus_component_set_call_state (dbus_component,
+					      GetCurrentCallToken (),
 					      GMManager::Standby);
 #endif
   gnomemeeting_threads_leave ();
 
   /* Update internal state */
   SetCallingState (GMManager::Standby);
-  old_token = GetCurrentCallToken ();
   SetCurrentCallToken ("");
 
   /* Try to update the devices use if some settings were changed 
@@ -1156,6 +1146,10 @@ GMManager::OnReleased (OpalConnection & connection)
     OpalManager::OnReleased (connection);
     return;
   }
+
+  /* we reset the no-data detection */
+  RTPTimer.Stop ();
+  stats.Reset ();
   
   /* Start time */
   if (connection.GetConnectionStartTime ().IsValid ())
@@ -1220,17 +1214,13 @@ GMManager::OnReleased (OpalConnection & connection)
   case OpalConnection::EndedByRemoteCongestion :
     msg_reason = g_strdup (_("Congested link to remote party"));
     break;
-  case OpalConnection::EndedByUnreachable :
-    msg_reason = g_strdup (_("Remote user is unreachable"));
-    break;
-  case OpalConnection::EndedByNoEndPoint :
-    msg_reason = g_strdup (_("Remote user is unreachable"));
-    break;
   case OpalConnection::EndedByHostOffline :
     msg_reason = g_strdup (_("Remote host is offline"));
     break;
   case OpalConnection::EndedByTemporaryFailure :
-    msg_reason = g_strdup (_("Remote user is offline"));
+  case OpalConnection::EndedByUnreachable :
+  case OpalConnection::EndedByNoEndPoint :
+    msg_reason = g_strdup (_("Remote user is unreachable"));
     break;
 
   default :
@@ -1425,22 +1415,25 @@ GMManager::SetPorts ()
   if (tcp_couple && tcp_couple [0] && tcp_couple [1]) {
 
     SetTCPPorts (atoi (tcp_couple [0]), atoi (tcp_couple [1]));
-    PTRACE (1, "Set TCP port range to " << atoi (tcp_couple [0])
-	    << atoi (tcp_couple [1]));
+    PTRACE (1, "Set TCP port range to " << setfill (':') 
+            << atoi (tcp_couple [0]) << ":"
+	    << atoi (tcp_couple [1])) << setfill (' ');
   }
 
   if (rtp_couple && rtp_couple [0] && rtp_couple [1]) {
 
     SetRtpIpPorts (atoi (rtp_couple [0]), atoi (rtp_couple [1]));
-    PTRACE (1, "Set RTP port range to " << atoi (rtp_couple [0])
-	    << atoi (rtp_couple [1]));
+    PTRACE (1, "Set RTP port range to " << setfill (':')
+            << atoi (rtp_couple [0]) << ":"
+	    << atoi (rtp_couple [1])) << setfill (' ');
   }
 
   if (udp_couple && udp_couple [0] && udp_couple [1]) {
 
     SetUDPPorts (atoi (udp_couple [0]), atoi (udp_couple [1]));
-    PTRACE (1, "Set UDP port range to " << atoi (udp_couple [0])
-	    << atoi (udp_couple [1]));
+    PTRACE (1, "Set UDP port range to " << setfill (':')
+            << atoi (udp_couple [0]) << ":"
+	    << atoi (udp_couple [1])) << setfill (' ');
   }
 
   g_free (tcp_port_range);
@@ -1566,27 +1559,34 @@ void
 GMManager::StartListeners ()
 {
   GtkWidget *main_window = NULL;
+  GtkWidget *druid = NULL;
+
+  GtkWidget *dialog = NULL;
 
   gchar *iface = NULL;
   WORD port = 0;
 
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
-  
+  druid = GnomeMeeting::Process ()->GetDruidWindow ();
+
   gnomemeeting_threads_enter ();
   iface = gm_conf_get_string (PROTOCOLS_KEY "interface");
   gnomemeeting_threads_leave ();
   
-
+  /* Create the H.323 and SIP listeners */
   if (h323EP) {
   
     gnomemeeting_threads_enter ();
     port = gm_conf_get_int (H323_KEY "listen_port");
     gnomemeeting_threads_leave ();
     
+    h323EP->RemoveListener (NULL);
     if (!h323EP->StartListener (iface, port)) {
 
       gnomemeeting_threads_enter ();
-      gnomemeeting_error_dialog (GTK_WINDOW (main_window), _("Error while starting the listener for the H.323 protocol"), _("You will not be able to receive incoming H.323 calls. Please check that no other program is already running on the port used by Ekiga."));
+      dialog = gnomemeeting_error_dialog (GTK_WINDOW (main_window), _("Error while starting the listener for the H.323 protocol"), _("You will not be able to receive incoming H.323 calls. Please check that no other program is already running on the port used by Ekiga."));
+      if (gtk_window_is_active (GTK_WINDOW (druid)))
+	gtk_widget_set_parent (dialog, druid);
       gnomemeeting_threads_leave ();
     }
   }
@@ -1597,10 +1597,84 @@ GMManager::StartListeners ()
     port = gm_conf_get_int (SIP_KEY "listen_port");
     gnomemeeting_threads_leave ();
     
+    sipEP->RemoveListener (NULL);
     if (!sipEP->StartListener (iface, port)) {
       
       gnomemeeting_threads_enter ();
-      gnomemeeting_error_dialog (GTK_WINDOW (main_window), _("Error while starting the listener for the SIP protocol"), _("You will not be able to receive incoming SIP calls. Please check that no other program is already running on the port used by Ekiga."));
+      dialog = gnomemeeting_error_dialog (GTK_WINDOW (main_window), _("Error while starting the listener for the SIP protocol"), _("You will not be able to receive incoming SIP calls. Please check that no other program is already running on the port used by Ekiga."));
+      if (gtk_window_is_active (GTK_WINDOW (druid)))
+	gtk_widget_set_parent (dialog, druid);
+      gnomemeeting_threads_leave ();
+    }
+  }
+
+  g_free (iface);
+}
+
+
+void
+GMManager::OnIPChanged (PTimer &,
+			INT)
+{
+  PIPSocket::InterfaceTable ifaces;
+  OpalTransportAddress current_address;
+  PIPSocket::Address current_ip;
+  
+  PString ip;
+  PINDEX i = 0;
+  
+  BOOL found_ip = FALSE;
+  
+  gchar *iface = NULL;
+
+  gnomemeeting_threads_enter ();
+  iface = gm_conf_get_string (PROTOCOLS_KEY "interface");
+  gnomemeeting_threads_leave ();
+
+  /* Detect the valid interfaces */
+  PIPSocket::GetInterfaceTable (ifaces);
+  if (ifaces.GetSize () <= 0) {
+  
+    g_free (iface);
+    return;
+  }
+  
+  /* Is there a listener? */
+  if (sipEP->GetListeners ().GetSize () > 0) 
+    current_address = sipEP->GetListeners ()[0].GetLocalAddress ();
+  else if (h323EP->GetListeners ().GetSize () > 0) 
+    current_address = h323EP->GetListeners ()[0].GetLocalAddress ();
+  else {
+
+    g_free (iface);
+    return;
+  }
+    
+  /* Are we listening on the correct interface? */
+  if (current_address.GetIpAddress (current_ip)) {
+
+    while (i < ifaces.GetSize () && !found_ip) {
+
+      ip = ifaces [i].GetAddress ().AsString ();
+
+      if (ip == current_ip.AsString ())
+	found_ip = TRUE;
+
+      i++;
+    }
+  }
+
+  if (!found_ip) {
+
+    PTRACE (4, "Ekiga\tIP Address changed, updating listeners.");
+
+    if (ifaces.GetSize () > 1) {
+      
+      /* This will update the UI and the listeners through a GConf
+       * Notifier.
+       */
+      gnomemeeting_threads_enter ();
+      GnomeMeeting::Process ()->DetectInterfaces ();
       gnomemeeting_threads_leave ();
     }
   }
@@ -1703,9 +1777,17 @@ BOOL
 GMManager::OnOpenMediaStream (OpalConnection & connection,
 			       OpalMediaStream & stream)
 {
+  GtkWidget *main_window = NULL;
+  
   if (!OpalManager::OnOpenMediaStream (connection, stream))
     return FALSE;
 
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
+
+  gnomemeeting_threads_enter ();
+  gm_main_window_update_calling_state (main_window, GMManager::Connected);
+  gnomemeeting_threads_leave ();
+
   if (pcssEP->GetMediaFormats ().FindFormat(stream.GetMediaFormat()) == P_MAX_INDEX)
     OnMediaStream (stream, FALSE);
 
@@ -1860,7 +1942,7 @@ GMManager::UpdateRTPStats (PTime start_time,
 
       stats.re_a_bytes = re_bytes;
       stats.tr_a_bytes = tr_bytes;
-      
+
       stats.total_packets += audio_session->GetPacketsReceived ();
       stats.lost_packets += audio_session->GetPacketsLost ();
       stats.late_packets += audio_session->GetPacketsTooLate ();
@@ -2028,17 +2110,6 @@ GMManager::OnGatewayIPTimeout (PTimer &,
 }
 
 
-void
-GMManager::OnOutgoingCall (PTimer &,
-			    INT) 
-{
-  pcssEP->PlaySoundEvent ("ring_tone_sound");
-
-  if (OutgoingCallTimer.IsRunning ())
-    OutgoingCallTimer.RunContinuous (PTimeInterval (0, 3));
-}
-
-
 BOOL 
 GMManager::DeviceVolume (PSoundChannel *sound_channel,
 			  BOOL is_encoding,
@@ -2206,13 +2277,25 @@ GMManager::SetCallOnHold (PString callToken,
 {
   PSafePtr<OpalCall> call = FindCallWithLock (callToken);
   OpalConnection *connection = NULL;
-  
+#ifdef HAS_DBUS
+  GObject *dbus_component = NULL;
+#endif  
+
+#ifdef HAS_DBUS
+  dbus_component = GnomeMeeting::Process ()->GetDbusComponent ();
+#endif
+
   if (call != NULL) {
 
     connection = GetConnection (call, TRUE);
 
     if (connection != NULL) {
 
+#ifdef HAS_DBUS
+      gnomemeeting_dbus_component_set_call_on_hold (dbus_component,
+						    callToken,
+						    state);
+#endif
       if (state) 
 	connection->HoldConnection ();
       else 
