@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -750,12 +750,20 @@ class GMManager : public OpalManager
 
  public:
 
+  /* DESCRIPTION  :  Notifier called every minute to check for IP changes.
+   * BEHAVIOR     :  Update the listeners. 
+   * PRE          :  /
+   */
+  PDECLARE_NOTIFIER(PTimer, GMManager, OnIPChanged);
+
+
   /* DESCRIPTION  :  Notifier called after 30 seconds of no media.
    * BEHAVIOR     :  Clear the calls.
    * PRE          :  /
    */
   PDECLARE_NOTIFIER(PTimer, GMManager, OnNoIncomingMediaTimeout);
 
+  
 #if 0
   /* DESCRIPTION  :  Notifier called periodically to update details on ILS.
    * BEHAVIOR     :  Register, unregister the user from ILS or udpate his
@@ -764,6 +772,7 @@ class GMManager : public OpalManager
    */
   PDECLARE_NOTIFIER(PTimer, GMManager, OnILSTimeout);
 #endif
+  
 
   /* DESCRIPTION  :  Notifier called periodically during calls.
    * BEHAVIOR     :  Refresh the statistics window of the Control Panel
@@ -778,17 +787,8 @@ class GMManager : public OpalManager
    *                 if IP Checking is enabled in the config database.
    * PRE          :  /
    */
-  PDECLARE_NOTIFIER(PTimer, GMManager, OnGatewayIPTimeout);
+  PDECLARE_NOTIFIER(PTimer, GMManager, OnGatewayIPTimeout);  
 
-  
-  /* DESCRIPTION  :  Notifier called every 2 seconds while waiting for an
-   *                 answer for an outging call.
-   * BEHAVIOR     :  Display an animation in the main winow and play a ring
-   *                 sound.
-   * PRE          :  /
-   */
-  PDECLARE_NOTIFIER(PTimer, GMManager, OnOutgoingCall);
-  
 
   GtkWidget *audio_transmission_popup;
   GtkWidget *audio_reception_popup;
@@ -801,7 +801,7 @@ class GMManager : public OpalManager
   PTimer ILSTimer;
   PTimer RTPTimer;
   PTimer GatewayIPTimer;
-  PTimer OutgoingCallTimer;
+  PTimer IPChangedTimer;
   PTimer NoIncomingMediaTimer;
     
   BOOL ils_registered;
