@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -72,6 +72,15 @@ public:
   GMPCSSEndpoint (GMManager &);
   ~GMPCSSEndpoint ();
 
+  
+  /* DESCRIPTION  :  /
+   * BEHAVIOR     :  Starts a call, play the dialtone.
+   * PRE          :  /
+   */
+  BOOL MakeConnection (OpalCall & call, 
+                       const PString & party,  
+                       void * userData);
+
 
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Accept the current incoming call.
@@ -88,28 +97,18 @@ public:
    *		     Display a popup if required.
    * PRE          :  /
    */
-  virtual void OnShowIncoming (const OpalPCSSConnection &);
+  virtual void OnShowIncoming (const OpalPCSSConnection &connection);
+
 
   //FIXME
-  virtual BOOL OnShowOutgoing (const OpalPCSSConnection &);
-  virtual PString OnGetDestination (const OpalPCSSConnection &);  
-  
-
-  /* DESCRIPTION  :  Call back when patching a media stream.
-   *                 This function is called when a connection has created 
-   *                 a new media patch between two streams.
-   * PRE          :  /
-   */
-  virtual void OnPatchMediaStream (const OpalPCSSConnection & connection, 
-				   BOOL isSource,
-				   OpalMediaPatch & patch);
+  virtual BOOL OnShowOutgoing (const OpalPCSSConnection &connection);
   
   
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Plays a sound event on its device.
    * PRE          :  /
    */
-  void PlaySoundEvent (PString);
+  void PlaySoundEvent (PString ev);
   
   
   /* DESCRIPTION  :  This callback is called when an audio channel has to
@@ -118,9 +117,9 @@ public:
    *                 impossible.
    * PRE          :  /
    */
-  PSoundChannel *CreateSoundChannel (const OpalPCSSConnection &, 
-				     const OpalMediaFormat &,
-				     BOOL);
+  PSoundChannel *CreateSoundChannel (const OpalPCSSConnection &connection,
+				     const OpalMediaFormat &format,
+				     BOOL is_source);
 
   
   /* DESCRIPTION  :  This callback is called when the connection is 
@@ -136,15 +135,29 @@ public:
    * BEHAVIOR     :  Stops the timers.
    * PRE          :  /
    */
-  void OnReleased (OpalConnection &);
+  void OnReleased (OpalConnection &connection);
+
+
+  // FIXME
+  virtual PString OnGetDestination (const OpalPCSSConnection &connection);  
+  
+
+  /* DESCRIPTION  :  Call back when patching a media stream.
+   *                 This function is called when a connection has created 
+   *                 a new media patch between two streams.
+   * PRE          :  /
+   */
+  virtual void OnPatchMediaStream (const OpalPCSSConnection & connection, 
+				   BOOL isSource,
+				   OpalMediaPatch & patch);
 
 
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Returns the playing and recording volume levels.
    * PRE          :  /
    */
-  void GetDeviceVolume (unsigned int &,
-			unsigned int &);
+  void GetDeviceVolume (unsigned int &play_vol,
+			unsigned int &record_vol);
 
 
   /* DESCRIPTION  :  /
@@ -152,8 +165,8 @@ public:
    *                 Returns FALSE if it fails.
    * PRE          :  /
    */
-  BOOL SetDeviceVolume (unsigned int,
-			unsigned int);
+  BOOL SetDeviceVolume (unsigned int play_vol,
+			unsigned int record_vol);
 
 private:
   
@@ -173,10 +186,20 @@ private:
    * PRE          :  /
    */
   PDECLARE_NOTIFIER(PTimer, GMPCSSEndpoint, OnCallPending);
+
   
+  /* DESCRIPTION  :  Notifier called every 2 seconds while waiting for an
+   *                 answer for an outging call.
+   * BEHAVIOR     :  Display an animation in the main winow and play a ring
+   *                 sound.
+   * PRE          :  /
+   */
+  PDECLARE_NOTIFIER(PTimer, GMPCSSEndpoint, OnOutgoingCall);
+  
+
   PTimer NoAnswerTimer;
   PTimer CallPendingTimer;
-
+  PTimer OutgoingCallTimer;
   
   GMManager & endpoint;
 
